package
module
Version:
v0.0.0-...-aa38a4b
Opens a new window with list of versions in this module.
Published: Apr 29, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
NewCommand creates the root tachograph CLI command tree.
type Option func(*config)
Option configures the CLI command tree.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.